﻿/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Collections.Generic;
using Xamarin.Forms;

namespace GalleryUI
{
    /// <summary>
    /// The main page of the gallery application.
    /// </summary>
    public class MainPage : ContentPage
    {
        // The size of thumbnail.
        private int SIZE = 108;

        /// <summary>
        /// Initializes a new instance of the <see cref="MainPage"/> class.
        /// </summary>
        public MainPage() : base()
        {
            Title = "Gallery";

            // Create a stack layout to wrap Grid object with padding 20.
            StackLayout mainLayout = new StackLayout
            {
                Padding = 20,
            };

            // Create a Grid object to show the thumbnail for image.
            Grid grid = new Grid()
            {
                VerticalOptions = LayoutOptions.FillAndExpand,
                RowDefinitions =
                {
                    // Two rows.
                    new RowDefinition { Height = new GridLength(SIZE, GridUnitType.Absolute) },
                    new RowDefinition { Height = new GridLength(SIZE, GridUnitType.Absolute) },
                },
                ColumnDefinitions =
                {
                    // Six columns.
                    new ColumnDefinition { Width = new GridLength(SIZE, GridUnitType.Absolute) },
                    new ColumnDefinition { Width = new GridLength(SIZE, GridUnitType.Absolute) },
                    new ColumnDefinition { Width = new GridLength(SIZE, GridUnitType.Absolute) },
                    new ColumnDefinition { Width = new GridLength(SIZE, GridUnitType.Absolute) },
                    new ColumnDefinition { Width = new GridLength(SIZE, GridUnitType.Absolute) },
                    new ColumnDefinition { Width = new GridLength(SIZE, GridUnitType.Absolute) },
                },
            };

            // Put image into grid view one by one.
            grid.Children.Add(new Image
            {
                Source = "0.jpg",
                Aspect = Aspect.Fill,
            }, 0, 1, 0, 1);

            grid.Children.Add(new Image
            {
                Source = "1.jpg",
                Aspect = Aspect.Fill,
            }, 1, 2, 0, 1);

            grid.Children.Add(new Image
            {
                Source = "2.jpg",
                Aspect = Aspect.Fill,
            }, 2, 3, 0, 1);

            grid.Children.Add(new Image
            {
                Source = "3.jpg",
                Aspect = Aspect.Fill,
            }, 3, 4, 0, 1);

            grid.Children.Add(new Image
            {
                Source = "4.jpg",
                Aspect = Aspect.Fill,
            }, 4, 5, 0, 1);

            grid.Children.Add(new Image
            {
                Source = "5.jpg",
                Aspect = Aspect.Fill,
            }, 5, 6, 0, 1);

            grid.Children.Add(new Image
            {
                Source = "6.jpg",
                Aspect = Aspect.Fill,
            }, 0, 1, 1, 2);

            grid.Children.Add(new Image
            {
                Source = "7.jpg",
                Aspect = Aspect.Fill,
            }, 1, 2, 1, 2);

            grid.Children.Add(new Image
            {
                Source = "8.jpg",
                Aspect = Aspect.Fill,
            }, 2, 3, 1, 2);

            grid.Children.Add(new Image
            {
                Source = "9.jpg",
                Aspect = Aspect.Fill,
            }, 3, 4, 1, 2);

            // Add grid view into stack layout.
            mainLayout.Children.Add(grid);

            // Build the page.
            Content = mainLayout;
        }
    }
}
